Ik

Struct Ik 

pub struct Ik {
    pub name: String,
    pub order: u32,
    pub skin: bool,
    pub bones: Vec<usize>,
    pub target: usize,
    pub mix: f32,
    pub softness: f32,
    pub bend_positive: bool,
    pub compress: bool,
    pub stretch: bool,
    pub uniform: bool,
}

Fields

name: String

The constraint name. This is unique for the skeleton.

order: u32

The ordinal for the order constraints are applied.

skin: bool

skin: If true, the constraint is only applied when the active skin has the constraint. Assume false if omitted.

bones: Vec<usize>

A list of 1 or 2 bone names whose rotation will be controlled by the constraint.

target: usize

The target bone.

mix: f32

mix: A value from 0 to 1 indicating the influence the constraint has on the bones, where 0 means only FK, 1 means only IK, and between is a mix of FK and IK. Assume 1 if omitted.

softness: f32

softness: A value for two bone IK, the distance from the maximum reach of the bones that rotation will slow. Assume 0 if omitted.

bend_positive: bool

bendPositive: If true, the bones will bend in the positive rotation direction. Assume false if omitted.

compress: bool

compress: If true, and only a single bone is being constrained, if the target is too close, the bone is scaled to reach it. Assume false if omitted.

stretch: bool

stretch: If true, and if the target is out of range, the parent bone is scaled to reach it. If more than one bone is being constrained and the parent bone has local nonuniform scale, stretch is not applied. Assume false if omitted.

uniform: bool

uniform: If true, and only a single bone is being constrained, and compress or stretch is used, the bone is scaled on both the X and Y axes. Assume false if omitted.