pub struct DetachedSkeletonState {
pub slots: Vec<(usize, usize, BoneState, usize, usize)>,
/* private fields */
}Expand description
A state manager when you can’t use a lifetime reference to a Skeleton.
Instead you must pass in a reference to the skeleton when calling methods on here.
Care is needed to make sure it’s the correct Skeleton instance, otherwise there will be errors.
Fields
slots: Vec<(usize, usize, BoneState, usize, usize)>Implementations